@@ -1,3 +1,4 @@
+import re
 import math
 from inspect import getfullargspec
 import warnings
@@ -21,6 +22,16 @@ class _LinearSystem(_System):
 
         self._canonical_coeffs_func = None
 
+    def __str__(self):
+        text = super().__str__()
+        divider = 'Configuration plot function'
+        parts = text.split(divider)
+
+        new_line_tmpl = 'Canonical coefficients function defined: {}\n'
+        new_line = new_line_tmpl.format('True' if self.canonical_coeffs_func is not None else 'False')
+
+        return parts[0] + new_line + divider + parts[1]
+
     @property
     def canonical_coeffs_func(self):
         """A function that returns the three linear coefficients of the left
@@ -49,10 +60,11 @@ class _LinearSystem(_System):
 
         Example
         =======
+        >>> from resonance.linear_systems import SingleDoFLinearSystem
         >>> sys = SingleDoFLinearSystem()
         >>> sys.constants['gravity'] = 9.8  # m/s**2
         >>> sys.constants['length'] = 1.0  # m
-        >>> sys.constnats['mass'] = 0.5  # kg
+        >>> sys.constants['mass'] = 0.5  # kg
         >>> sys.coordinates['theta'] = 0.3  # rad
         >>> sys.speeds['omega'] = 0.0  # rad/s
         >>> def coeffs(gravity, length, mass):
@@ -81,8 +93,40 @@ class _LinearSystem(_System):
         self._canonical_coeffs_func = func
 
     def canonical_coefficients(self):
-        """Returns the mass, damping, and stiffness coefficients in that
-        order."""
+        """Returns the mass, damping, and stiffness coefficients of the
+        canonical second order differential equation.
+
+
+        Returns
+        =======
+        m : float
+            System mass coefficient.
+        c : float
+            System damping coefficient.
+        k : float
+            System stiffness coefficient.
+
+        Example
+        =======
+        >>> from resonance.linear_systems import SingleDoFLinearSystem
+        >>> sys = SingleDoFLinearSystem()
+        >>> sys.constants['gravity'] = 9.8  # m/s**2
+        >>> sys.constants['length'] = 1.0  # m
+        >>> sys.constants['mass'] = 0.5  # kg
+        >>> sys.coordinates['theta'] = 0.3  # rad
+        >>> sys.speeds['omega'] = 0.0  # rad/s
+        >>> def coeffs(gravity, length, mass):
+        >>>     # Represents a linear model of a simple pendulum:
+        ...     #  m * l**2 ω' + m * g * l * θ = 0
+        ...     I = mass * length**2
+        ...     c = 0.0
+        ...     k = mass * gravity * length
+        ...     return I, c, k
+        >>> sys.canonical_coeffs_func = coeffs
+        >>> sys.canonical_coefficients()
+        (0.5, 0.0, 4.9)
+
+        """
         self._check_system()
         if self.canonical_coeffs_func is None:
             msg = ('There is no function available to calculate the canonical'
@@ -516,8 +560,8 @@ class SingleDoFLinearSystem(_LinearSystem):
             raise ValueError('{} already taken.'.format(col_name))
         else:
             self.result[col_name] = twice_avg / 2 + \
-                np.sum(an * n * np.cos(frequency * n * t) +
-                       bn * n * np.sin(frequency * n * t), axis=0)
+                np.sum(an * np.cos(frequency * n * t) +
+                       bn * np.sin(frequency * n * t), axis=0)
 
         return self.result
 
@@ -715,6 +759,20 @@ class MultiDoFLinearSystem(_MDNLS):
         self._forcing_func = None
         self._compute_forcing = False
 
+    def __str__(self):
+        text = super().__str__()
+
+        pattern = 'Differential equations function defined.*\n'
+        text = re.sub(pattern, '', text)
+
+        divider = 'Configuration plot function'
+        parts = text.split(divider)
+
+        new_line_tmpl = 'Canonical coefficients function defined: {}\n'
+        new_line = new_line_tmpl.format('True' if self.canonical_coeffs_func is not None else 'False')
+
+        return parts[0] + new_line + divider + parts[1]
+
     @property
     def canonical_coeffs_func(self):
         """A function that returns the three linear coefficient matrices of the
