@@ -58,8 +58,17 @@ class _StatesDict(_collections.OrderedDict):
         else:
             raise ValueError(msg)
 
+    def __str__(self):
+        pairs = []
+        for k, v in self.items():
+            pairs.append("'{}': {}".format(k, v))
+        return '{' + ', '.join(pairs) + '}'
 
-class _CoordinatesDict(_collections.OrderedDict):
+    def __repr__(self):
+        return self.__str__()
+
+
+class _CoordinatesDict(_StatesDict):
     """A custom dictionary for storing coordinates and speeds."""
 
     def __setitem__(self, key, value):
@@ -130,9 +139,9 @@ class _MeasurementsDict(_abc.MutableMapping, dict):
                 raise KeyError(msg.format(k))
             return v
 
-        # TODO : getfullargspec is deprecated, supposedly signature can do the same
-        # thing but the args are in a dictionary and it isn't clear to me they
-        # are ordered.
+        # TODO : getfullargspec is deprecated, supposedly signature can do the
+        # same thing but the args are in a dictionary and it isn't clear to me
+        # they are ordered.
         args = [get_par(k) for k in getfullargspec(func).args]
         return func(*args)
 
@@ -190,6 +199,48 @@ class System(object):
         self._config_plot_func = None
         self._config_plot_update_func = None
 
+    def __str__(self):
+        text = """\
+System name: {name}
+
+Configuration plot function defined: {plot}
+Configuration update function defined: {update}
+
+Constants
+=========
+{constants}
+
+Coordinates
+===========
+{coordinates}
+
+Speeds
+======
+{speeds}
+
+Measurements
+============
+{measurements}"""
+
+        ls = lambda d: '\n'.join('{} = {:1.5f}'.format(k, v) for k, v in d.items())
+
+        speed_tmpl = '{} = d({})/dt = {:1.5f}'
+        speed_strs = []
+        for gs, gc in zip(self.speeds.keys(), self.coordinates.keys()):
+            speed_strs.append(speed_tmpl.format(gs, gc, self.speeds[gs]))
+
+        return text.format(
+            name=self.__class__.__name__,
+            plot='True' if self.config_plot_func is not None else 'False',
+            update='True' if self.config_plot_update_func is not None else 'False',
+            constants=ls(self.constants),
+            coordinates=ls(self.coordinates),
+            speeds='\n'.join(speed_strs),
+            measurements=ls(self.measurements))
+
+    def __repr__(self):
+        return self.__str__()
+
     @property
     def constants(self):
         """A dictionary containing the all of the system's constants, i.e.
@@ -308,7 +359,7 @@ class System(object):
     @property
     def config_plot_func(self):
         """The configuration plot function arguments should be any of the
-        system's constants, coordinates, measurements, or 'time'. No other
+        system's constants, coordinates, measurements, or ``'time'``. No other
         arguments are valid. The function has to return the matplotlib figure
         as the first item but can be followed by any number of mutable
         matplotlib objects that you may want to change during an animation.
@@ -366,7 +417,6 @@ class System(object):
         ...     # in the same order as returned from plot()
         ...     circle.set_xy((center_x, center_y))
         ...     ax.set_title(time)
-        ...     fig.canvas.draw()
         ...
         >>> sys.config_plot_update_func = update
         >>> sys.animate_configuration()
@@ -394,7 +444,7 @@ class System(object):
     def _get_par_vals(self, par_name):
         """Returns the value of any variable stored in the parameters,
         coordinates, or measurements dictionaries."""
-        # TODO : This get for duplicates is slow and called way too often.
+        # TODO : This check for duplicates is slow and called way too often.
         self._measurements._check_for_duplicate_keys()
         # TODO : This is duplicate of similar code in
         # _MeasurementsDict._compute_value(). Shouldn't have this redundancy.
@@ -477,10 +527,10 @@ class System(object):
             This string can be different that the function name.
         func : function
             This function must only have existing constant, coordinate, speed,
-            or measurement names, and/or the special name "time" in the function
-            signature. These can be a subset of the available choices in
-            constants, coordinates, speeds, measurements and any order in the
-            signature is permitted. The function must be able to operate on
+            or measurement names, and/or the special name ``'time'`` in the
+            function signature. These can be a subset of the available choices
+            in constants, coordinates, speeds, measurements and any order in
+            the signature is permitted. The function must be able to operate on
             both inputs that are a collection of floats or a collection of
             equal length 1D NumPy arrays and floats, i.e. the function must be
             vectorized. So be sure to use NumPy vectorized functions inside
@@ -621,7 +671,7 @@ class System(object):
         """Returns a data frame with monotonic time values as the index and
         columns for each coordinate and measurement at the time value for that
         row. Note that this data frame is stored on the system as the variable
-        ``result`` until this method is called again, which will overwrite it.
+        ``.result`` until this method is called again, which will overwrite it.
 
         Parameters
         ==========
